@@ -32,24 +32,21 @@ def update_config_file(new_config):
     if not os.path.exists(os.path.dirname(settings.PATH_TO_MS_CONFIG)):
         try:
             os.makedirs(os.path.dirname(settings.PATH_TO_MS_CONFIG))
+            with open(settings.PATH_TO_MS_CONFIG, 'w+') as outfile:
+                json.dump({}, outfile)
         except OSError as exc:  # Guard against race condition
             if exc.errno != errno.EEXIST:
                 raise
 
     # Read file
-    try:
-        with open(settings.PATH_TO_MS_CONFIG) as json_file:
-            if len(json_file.read()) >= 1:
-                data = json.loads(json_file.read())
-            else:
-                data = {}
-    except FileNotFoundError:
-        data = {}
+    with open(settings.PATH_TO_MS_CONFIG) as json_file:
+        data = json.load(json_file)
+        print(data)
 
     # Prepare config to insert
     unique_integration = f"{new_config['monitoring_system']}_{new_config['integration_name']}"
     if unique_integration in data:
-        return f'Integration already exist in configuration - {unique_integration}'
+        print(f'Integration - "{unique_integration}" already exist in configuration - {settings.PATH_TO_MS_CONFIG}')
     else:
         data[unique_integration] = new_config
 
